import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '文件名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '描述',
    dataIndex: 'remark',
    width: 150,
  },
  {
    title: '权属机构',
    dataIndex: 'workgroup',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 150,
  },
  {
    title: '版本发布状态',
    dataIndex: 'status',
    width: 150,
  },
  {
    title: '上架状态',
    dataIndex: 'uploadStatus',
    width: 100,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 5 },
    componentProps: {
      placeholder: '搜索文件名称',
    },
  },
  {
    field: 'workGroup',
    label: ' ',
    component: 'Select',
    colProps: { span: 5 },
    componentProps: {
      placeholder: '权属机构',
      options: [
        { label: '测试功能部', value: '11' },
        { label: '开发部', value: '12' },
        { label: '市场部', value: '13' },
        { label: '财务部', value: '14' },
      ],
    },
  },
  {
    field: 'status',
    label: ' ',
    component: 'Select',
    colProps: { span: 5 },
    componentProps: {
      placeholder: '版本发布状态',
      options: [
        { label: '已发布', value: '0' },
        { label: '未发布', value: '1' },
      ],
    },
  },
  {
    field: 'uploadStatus',
    label: ' ',
    component: 'Select',
    colProps: { span: 5 },
    componentProps: {
      placeholder: '上架状态',
      options: [
        { label: '已上架', value: '0' },
        { label: '未上架', value: '1' },
      ],
    },
  },
];
export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      // border: 'none',
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];
export const formSchemaNewFolder: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '文件夹名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件夹名称',
    },
  },
];
export const addFileFormSchema: any = [
  {
    field: 'path',
    label: '文件路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '文件名称',
    component: 'Input',
    componentProps: {
      placeholder: '输入文件名称',
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const editFileFormSchema: any = [
  {
    field: 'name',
    label: '文件名称',
    component: 'Input',
    required: true,
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'path',
    label: '文件路径',
    component: 'TreeSelect',
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'remark',
    label: '描述',
    component: 'Input',
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'workGroup',
    label: '权属机构',
    component: 'TreeSelect',
    componentProps: {
      placeholder: '请选择权属机构',
      treeData: [
        {
          title: '部门',
          businessId: '1',
          parentId: '0',
          children: [
            {
              title: '测试功能部',
              businessId: '11',
              parentId: '1',
            },
            {
              title: '开发部',
              businessId: '12',
              parentId: '1',
            },
            {
              title: '市场部',
              businessId: '13',
              parentId: '1',
            },
            {
              title: '财务部',
              businessId: '14',
              parentId: '1',
            },
          ],
        },
      ],
      fieldNames: {
        label: 'title',
        value: 'businessId',
      },
    },
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'tag',
    label: '业务标签',
    component: 'Select',
    componentProps: {
      placeholder: '请选择业务标签',
      options: [
        { label: '测试', value: '测试' },
        { label: '开发', value: '开发' },
        { label: '市场', value: '市场' },
        { label: '财务', value: '财务' },
      ],
    },
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'sensitive',
    label: '敏感状态',
    component: 'Select',
    componentProps: {
      placeholder: '请选择敏感状态',
      options: [
        { label: '敏感', value: '敏感' },
        { label: '不敏感', value: '不敏感' },
      ],
    },
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'security',
    label: '安全分级',
    component: 'Select',
    componentProps: {
      placeholder: '请选择安全分级',
      options: [
        { label: 'A级', value: 'A级' },
        { label: 'B级', value: 'B级' },
        { label: 'C级', value: 'C级' },
        { label: 'D级', value: 'D级' },
      ],
    },
    colProps: { lg: 10, md: 10 },
  },
];
export const editFilePermissionsFormSchema: any = [
  {
    field: 'download',
    label: '下载权限',
    component: 'Switch',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'encrypt',
    label: '文件加密',
    component: 'Switch',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
];
export const editFileOptionsFormSchema: any = [
  {
    field: 'autoOffShelfDate',
    label: '自动下架日期',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'shareType',
    label: '共享方式',
    component: 'Select',
    componentProps: {
      placeholder: '请选择共享方式',
      options: [
        { label: '公开', value: '公开' },
        { label: '私有', value: '私有' },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'visibleRange',
    label: '可见范围',
    component: 'Select',
    componentProps: {
      placeholder: '请选择可见范围',
      options: [
        { label: '公开', value: '公开' },
        { label: '私有', value: '私有' },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
];
